@@ -1,6 +1,6 @@
 # main.py
 #
-# Copyright 2019 Romain F. T.
+# Copyright 2018-2020 Romain F. T.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -260,11 +260,14 @@ class Application(Gtk.Application):
 	def on_about(self, *args):
 		"""Action callback, showing the "about" dialog."""
 		about_dialog = Gtk.AboutDialog(transient_for=self.props.active_window,
-			copyright='© 2019 Romain F. T.', authors=['Romain F. T.'],
+			copyright="© 2018-2020 Romain F. T.", authors=["Romain F. T."],
 			# To tranlators: "translate" this by your name, it will be displayed
 			# in the "about" dialog
 			translator_credits=_("translator-credits"),
-			artists=['Tobias Bernard', 'Romain F. T.'],
+			# To translators: it's credits for the icons, consider that "Art
+			# Libre" is proper name
+			artists=["Tobias Bernard", "Romain F. T.",
+			                       _("GNOME's \"Art Libre\" icon set authors")],
 			comments=_("A drawing application for the GNOME desktop."),
 			license_type=Gtk.License.GPL_3_0,
 			logo_icon_name=APP_ID, version=str(self.version),
@@ -274,8 +277,28 @@ class Application(Gtk.Application):
 		about_dialog.destroy()
 
 	def on_quit(self, *args):
-		"""Action callback, quitting the app."""
-		self.quit()
+		"""Action callback, quitting the entire app."""
+		if self.shortcuts_window is not None:
+			self.shortcuts_window.destroy()
+		if self.prefs_window is not None:
+			self.prefs_window.destroy()
+
+		can_quit = True
+		# Try (= ask confirmation) to quit the main window(s)
+		main_windows = self.get_windows()
+		for w in main_windows:
+			if w.on_close():
+				# User clicked on "cancel"
+				can_quit = False
+			else:
+				w.close()
+				w.destroy()
+
+		# The expected behavior, but now theorically useless, since closing all
+		# appwindows should quit automatically. It's too violent to be left
+		# without a guard clause.
+		if can_quit:
+			self.quit()
 
 	# UTILITIES ################################################################
 
