@@ -3,10 +3,10 @@
 from gi.repository import Gtk, Gdk
 import cairo
 
-from .abstract_tool import ToolTemplate
+from .abstract_tool import AbstractAbstractTool
 from .utilities import utilities_generic_shape_tool_operation
 
-class ToolPolygon(ToolTemplate):
+class ToolPolygon(AbstractAbstractTool):
 	__gtype_name__ = 'ToolPolygon'
 
 	def __init__(self, window, **kwargs):
@@ -16,37 +16,20 @@ class ToolPolygon(ToolTemplate):
 		(self.x_press, self.y_press) = (-1.0, -1.0)
 		(self.past_x, self.past_y) = (-1.0, -1.0)
 		self.selected_style_id = 'secondary'
-		self.selected_style_label = _("Filled (secondary color)")
 		self.selected_join_id = cairo.LineJoin.MITER
 
 		self.add_tool_action_enum('filling_style', 'secondary')
-	# 	self.add_tool_action_enum('angle_style', 'miter')
-
-	# def set_angle_style(self, *args):
-	# 	state_as_string = self.get_option_value('angle_style')
-	# 	if state_as_string == 'bevel':
-	# 		self.selected_join_id = cairo.LineJoin.BEVEL
-	# 	elif state_as_string == 'miter':
-	# 		self.selected_join_id = cairo.LineJoin.MITER
-	# 	else:
-	# 		self.selected_join_id = cairo.LineJoin.ROUND
 
 	def set_filling_style(self):
 		state_as_string = self.get_option_value('filling_style')
 		self.selected_style_id = state_as_string
-		if state_as_string == 'empty':
-			self.selected_style_label = _("Empty")
-		elif state_as_string == 'filled':
-			self.selected_style_label = _("Filled (main color)")
-		else:
-			self.selected_style_label = _("Filled (secondary color)")
 
 	def get_options_label(self):
 		return _("Polygon options")
 
 	def get_edition_status(self):
 		self.set_filling_style()
-		label = self.label + ' - ' + self.selected_style_label
+		label = self.label + ' - ' + _("Click on the shape's first point to close it.")
 		return label
 
 	def give_back_control(self, preserve_selection):
@@ -77,7 +60,7 @@ class ToolPolygon(ToolTemplate):
 			self.continue_polygon(cairo_context, event_x, event_y)
 			return False
 
-	def init_polygon(self, cairo_context): # TODO simplfiable depuis que c'est split en 2 outils
+	def init_polygon(self, cairo_context): # TODO simplifiable ?
 		(self.past_x, self.past_y) = (self.x_press, self.y_press)
 		cairo_context.move_to(self.x_press, self.y_press)
 		self._path = cairo_context.copy_path()
@@ -97,11 +80,7 @@ class ToolPolygon(ToolTemplate):
 		operation = self.build_operation(cairo_context.copy_path())
 		self.do_tool_operation(operation)
 
-	def on_motion_on_area(self, area, event, surface, event_x, event_y):
-		self.restore_pixbuf()
-		self.draw_polygon(event_x, event_y, True)
-
-	def on_press_on_area(self, area, event, surface, tool_width, left_color, right_color, event_x, event_y):
+	def on_press_on_area(self, event, surface, tool_width, left_color, right_color, event_x, event_y):
 		self.x_press = event_x
 		self.y_press = event_y
 		self.tool_width = tool_width
@@ -112,7 +91,11 @@ class ToolPolygon(ToolTemplate):
 			self.main_color = left_color
 			self.secondary_color = right_color
 
-	def on_release_on_area(self, area, event, surface, event_x, event_y):
+	def on_motion_on_area(self, event, surface, event_x, event_y):
+		self.restore_pixbuf()
+		self.draw_polygon(event_x, event_y, True)
+
+	def on_release_on_area(self, event, surface, event_x, event_y):
 		self.restore_pixbuf()
 		finished = self.draw_polygon(event_x, event_y, False)
 		if finished:
